window.Gleam.initSearch([{"doc":"pathern","title":"pathern","content":"# Pathern (path + pattern)\n[![Package Version](https://img.shields.io/hexpm/v/pathern)](https://hex.pm/packages/pathern)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/pathern/)\n\nA URL path pattern matching library for the Gleam programming language.\n\n## Installation\n\n```\ngleam add pathern@0.1.0\n\n```\n\n\n## Usage\n\n```gleam\nimport gleeunit/should\nimport pathern\n\npub fn main() {\n\n  // Path parameter match\n  // path: &quot;/user/juliet&quot;\n  // pattern: &quot;/user/:name&quot;\n  //\n  // returns: (path: &quot;/user/juliet&quot;, pattern: &quot;/user/:name&quot;, params: [#(&quot;name&quot;, &quot;juliet&quot;)])\n  pathern.match(&quot;/user/juliet&quot;, &quot;/user/:name&quot;)\n  |&gt; should.equal(\n    Ok(pathern.Pathern(\n      &quot;/user/juliet&quot;,\n      &quot;/user/:name&quot;,\n      dict.from_list([#(&quot;name&quot;, &quot;juliet&quot;)]),\n    )),\n  )\n\n  // Path parameter without match\n  // path: &quot;/user/juliet&quot;\n  // pattern: &quot;/create/:name&quot;\n  //\n  // returns: Error(Nil)\n  pathern.match(&quot;/user/juliet&quot;, &quot;/create/:name&quot;)\n  |&gt; should.be_error()\n\n  // Path parameter match against a list of patterns\n  // path: &quot;/user/juliet/123&quot;\n  // patterns: [&quot;/&quot;, &quot;/user&quot;, &quot;/name&quot;, &quot;/user/:name/:id&quot;]\n  //\n  // returns: (path: &quot;/user/juliet&quot;, pattern: &quot;/user/:name&quot;, params: [#(&quot;name&quot;, &quot;juliet&quot;), #(&quot;id&quot;, &quot;123&quot;)])\n  pathern.match_patterns(&quot;/user/juliet/123&quot;, [&quot;/&quot;, &quot;/user&quot;, &quot;/name&quot;, &quot;/user/:name/:id&quot;])\n  |&gt; should.equal(\n    Ok(pathern.Pathern(\n      &quot;/user/juliet/123&quot;,\n      &quot;/user/:name/:id&quot;,\n      dict.from_list([#(&quot;name&quot;, &quot;juliet&quot;), #(&quot;id&quot;, &quot;123&quot;)]),\n    )),\n  )\n\n  // Path parameter without a match against a list of patterns\n  // path: &quot;/user/juliet&quot;\n  // patterns: [&quot;/&quot;, &quot;/user&quot;, &quot;/name&quot;, &quot;/list/:name&quot;]\n  //\n  // returns: Error(Nil)\n  pathern.match_patterns(&quot;/user/juliet&quot;, [&quot;/&quot;, &quot;/user&quot;, &quot;/name&quot;, &quot;/list/:name&quot;])\n  |&gt; should.be_error()\n\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/pathern&gt;.\n\n## Patterns supported\n\n[x] Root (`&quot;/&quot;`)\n\n[x] Exact path (`&quot;/user/&quot;`)\n\n[x] Path parameters (`&quot;/user/:name/&quot;`)\n\n[ ] Optional parameter (`&quot;/user/:name?/&quot;`)\n\n[ ] Wildcard (`&quot;/user/*&quot;`)\n\n[ ] Regex (`&quot;/user/:id{[0-9]+}/&quot;`)\n\n[ ] Query string (`&quot;/user?id={:id}&quot;`)\n","url":"index.html"},{"doc":"pathern","title":"Pathern","content":"pub type Pathern {\n  Pathern(\n    path: String,\n    pattern: String,\n    params: Dict(String, String),\n  )\n}\n A Pathern type is the result if there is a match\n \n It contains the input path, the pattern that matched, and the parameters extraced from the path, if any\nPathern(\n  path: String,\n  pattern: String,\n  params: Dict(String, String),\n)\n\n\nSynonyms:\npathern.Pathern\npathern Pathern","url":"pathern.html#Pathern"},{"doc":"pathern","title":"match","content":"pub fn match(\n  path: String,\n  pattern: String,\n) -&gt; Result(Pathern, Nil)\n Matches the path against the pattern\n \n Returns either a `Pathern` or an `Error(Nil)`\n \n ## Examples\n \n \n match(&quot;/user/jane&quot;, &quot;/user/:name&quot;)\n -&gt; Pathern(path: &quot;/user/jane&quot;, pattern: &quot;/user/:name&quot;, params: [#(&quot;name&quot;, &quot;jane&quot;)])\n \n \n \n match(&quot;/user/jane&quot;, &quot;/user&quot;)\n -&gt; Error(Nil)\n \n \nSynonyms:\npathern.match\npathern match","url":"pathern.html#match"},{"doc":"pathern","title":"match_patterns","content":"pub fn match_patterns(\n  path: String,\n  patterns: List(String),\n) -&gt; Result(Pathern, Nil)\n Matches the path against the list of patterns\n \n Returns either a `Pathern` or an `Error(Nil)`\n \n ## Examples\n \n \n match_patterns(&quot;/user/jane&quot;, [&quot;/user&quot;, &quot;/user/:name&quot;])\n -&gt; Pathern(path: &quot;/user/jane&quot;, pattern: &quot;/user/:name&quot;, params: [#(&quot;name&quot;, &quot;jane&quot;)])\n \n \n \n match_patterns(&quot;/user/jane&quot;, [&quot;/user&quot;, &quot;/&quot;])\n -&gt; Error(Nil)\n \n \nSynonyms:\npathern.match_patterns\npathern match_patterns","url":"pathern.html#match_patterns"},{"doc":"pathern","title":"pathern","content":"","url":"pathern.html"}]);